@@ -11,5 +11,5 @@ pub fn add_student(name: &str) {
 }
 
 pub fn take_attendance() {
-    println!("Class 1 have 3 student, There are Allen, Steven , Mark. ")
+    println!("Class 1 have 3 student, There are Allen, Steven, Mark, ")
 }
